<?php

/* DCMS Special
 * Дата последнего редактирования 09.10.2016
 * Модифицировал densnet
 */

if (isset($_GET['act']) && $_GET['act'] == 'frend') {
    $k_post = $db->super_query("SELECT COUNT(*) as count FROM `friends` WHERE `user` = '$ank[id]' AND `i` = '1'");
    $k_post = $k_post['count'];
    $q = $db->query("SELECT * FROM `friends` WHERE `user` = '$ank[id]' AND `i` = '1' ORDER BY time DESC");
    if (isset($user) && $user['id'] == $ank['id']) {
        if ($k_post > 0) {
            echo "<form method='post' action='?'>";
        }
    }

    if ($k_post == 0) {
        $doc->NoResult();
    }

    echo "<div class='list-group-item-null'>";
    while ($frend = $db->get_row($q)) {
        $friend = get_user($frend['friends']);

        if (isset($user) && $user['id'] == $ank['id']) {
            echo "<input type='checkbox' name='post_$friend[id]' value='1' /> ";
        }
        echo user($friend['id']);
        echo "<br />";
    }
    echo "</div>";


    if (isset($user) && $user['id'] == $ank['id']) {
        if ($k_post > 0) {
            echo "<div class='list-group-item-null'>";
            echo lang('Отмеченных друзей') . ":<br />";
            echo "<input value=\"Отметить\" type=\"submit\" name=\"metka\" /> <input value=\"Снять метку\" type=\"submit\" name=\"delete\" /> ";
            echo "</div>";
            echo "</form>\n";
        }
    }
    require_once H . 'sys/inc/tfoot.php';
    exit;
}

if (isset($_GET['act']) && $_GET['act'] == 'delete') {
    echo "<div class='list-group-item-null'>" . lang('Удаление') . "<a style = 'float:right;color: grey;' href = '?'><small>" . lang('Закрыть') . "</small></a></div>";

    echo "<form class='list-group-item-null' action='?act=delete&amp;ok' method='post'>";
    echo lang('Подтвердите удаление фотографии') . "<br />";

    $doc->Button('btn btn-success btn-sm', null, 'trash-o', 'Удалить');
    echo "</form>";

    require_once H . 'sys/inc/tfoot.php';
    exit();
}

if (isset($_GET['act']) && $_GET['act'] == 'edit') {
    echo "<div class = 'list-group-item-null list-group-item-info'>" . lang('Редактирование') . "<a style = 'float:right;color: grey;' href = '?'><small>" . lang('Закрыть') . "</small></a></div>";
    echo "<div class = 'list-group-item-null list-group-item-grey'>";
    echo "<center><img src='/modules/foto/foto128/$foto[id].jpg' /><br /><a href='?act=edit&amp;rotate=left'><i class='fa fa-rotate-left'></i></a> <a href='?act=edit&amp;rotate=right'><i class='fa fa-rotate-right'></i></a></center>\n";
    echo "</div>";
    echo "<form class='list-group-item-null' action = '?act=edit&amp;ok' method = 'post'>";
    $doc->Input('name', 'Название', 32, "$foto[name]");
    $doc->Textarea('opis', 'Описание', 256, "" . toOutput($foto['opis']) . "");
    echo "<br />";
    $doc->Checkbox('adult', '18+', '1', "" . ($foto['adult'] == 1 ? " checked='checked'" : NULL) . "");
    echo "<br />";
    echo "<b>" . lang('Кто может комментировать') . "?</b><br />\n";
    $doc->Radio('komm', 'Все', 'all', "" . ($foto['komm'] == 'all' ? " checked='checked'" : null) . "", 'unlock');
    $doc->Radio('komm', 'Только я', 'only_me', "" . ($foto['komm'] == 'only_me' ? " checked='checked'" : null) . "", 'lock');
    $doc->Radio('komm', 'Только друзья', 'friends', "" . ($foto['komm'] == 'friends' ? " checked='checked'" : null) . "", 'users');

    echo "<br />";

    $doc->Button('btn btn-success btn-sm', null, 'save', 'Сохранить');
    echo "</form>";

    require_once H . 'sys/inc/tfoot.php';
    exit();
}

if (isset($_GET['act']) && $_GET['act'] == 'avatar' && $ank['id'] == $user['id']) {
    echo "<form class='list-group-item-null list-group-item-info' action='?act=avatar&amp;ok' method=\"post\">";
    echo lang('Вы уверены?') . "<br />";

    $doc->Button('btn btn-success btn-sm', null, 'check', 'Установить');
    $doc->Link('btn btn-secondary btn-sm', '?', null, 'Отмена');
    echo "</form>";
}

$doc->Link('list-group-item-null', "?act=avatar", 'image', 'Сделать фотографией профиля');
$doc->Link('list-group-item-null', "?act=frend", 'users', 'Отметить друзей');
$doc->Link('list-group-item-null', "/modules/foto/create.php?foto=$foto[id]&amp;get", 'expand', 'Редактировать миниатюры');
$doc->Link('list-group-item-null', "?act=edit", 'edit', 'Параметры фото');
$doc->Link('list-group-item-null', "?act=delete", 'trash-o', 'Удалить фото');
